@@ -1,3 +1,5 @@
+tol_large = 1e-10
+
 # Multiple groups / outcomes: effect size estimates
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: SMD", {
   df <- df.SMD;   df$factor <- "Pharma"; df$amstar <- 7
@@ -38,8 +40,8 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 
   df.mfr <- df.mfr[order(df.mfr$author, df.mfr$year), ]
 
-  expect_equal(df.agg.umb$value, as.numeric(as.character(df.mfr$yi)), tolerance = 1e-9)
-  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = 1e-9)
+  expect_equal(df.agg.umb$value, as.numeric(as.character(df.mfr$yi)), tolerance = tol_large)
+  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = tol_large)
 })
 
 
@@ -73,8 +75,8 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 
   df.mfr <- df.mfr[order(df.mfr$author, df.mfr$year), ]
 
-  expect_equal(df.agg.umb$value, exp(as.numeric(as.character(df.mfr$yi))), tolerance = 1e-15)
-  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = 1e-15)
+  expect_equal(df.agg.umb$value, exp(as.numeric(as.character(df.mfr$yi))), tolerance = tol_large)
+  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = tol_large)
 })
 
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: RR", {
@@ -105,8 +107,8 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 
   df.mfr <- df.mfr[order(df.mfr$author, df.mfr$year), ]
 
-  expect_equal(df.agg.umb$value, exp(as.numeric(as.character(df.mfr$yi))), tolerance = 1e-15)
-  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = 1e-15)
+  expect_equal(df.agg.umb$value, exp(as.numeric(as.character(df.mfr$yi))), tolerance = tol_large)
+  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = tol_large)
 })
 
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: IRR", {
@@ -149,8 +151,8 @@ test_that("agg.data correctly aggregates studies with multiple effect size estim
 
   df.mfr <- df.mfr[order(df.mfr$author, df.mfr$year), ]
 
-  expect_equal(df.agg.umb$value, exp(as.numeric(as.character(df.mfr$yi))), tolerance = 1e-14)
-  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = 1e-15)
+  expect_equal(df.agg.umb$value, exp(as.numeric(as.character(df.mfr$yi))), tolerance = tol_large)
+  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = tol_large)
 })
 
 test_that("agg.data correctly aggregates studies with multiple effect size estimates: HR", {
@@ -183,10 +185,225 @@ df$n_controls = with(df, n_controls_exp + n_controls_nexp)
 
   df.mfr <- df.mfr[order(df.mfr$author, df.mfr$year), ]
 
-  expect_equal(df.agg.umb$value, exp(as.numeric(as.character(df.mfr$yi))), tolerance = 1e-15)
-  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = 1e-15)
+  expect_equal(df.agg.umb$value, exp(as.numeric(as.character(df.mfr$yi))), tolerance = tol_large)
+  expect_equal(df.agg.umb$se, sqrt(df.mfr$vi), tolerance = tol_large)
 })
 
+###############################################################################################
+# Multiple groups / outcomes: effect size estimates
+test_that("agg.data correctly aggregates studies with multiple effect size estimates: SMD", {
+  df <- df.SMD;   df$factor <- "Pharma"; df$amstar <- 7
+  D = with(df, .estimate_d_from_means(n_cases, n_controls, mean_cases, sd_cases, mean_controls, sd_controls))
+  G = with(df, .estimate_g_from_d(value, n_cases, n_controls))
+  df$value = G$value
+  df$se = G$se
+
+  df$author[c(2,3, 5,6,7, 15,16,17)] <- c(df$author[1], df$author[1],
+                                          df$author[4], df$author[4], df$author[4],
+                                          df$author[14], df$author[14], df$author[14])
+
+  df$year[c(2,3, 5,6,7, 15,16,17)] <- c(df$year[1], df$year[1],
+                                        df$year[4], df$year[4], df$year[4],
+                                        df$year[14], df$year[14], df$year[14])
+
+  df$multiple_es <- NA ; df$multiple_es[c(1,2,3, 4,5,6,7)] <- "groups"
+  df$multiple_es[c(14,15,16,17)] <- "outcomes"
+
+  df.agg.mfr <- metafor::escalc(yi = value, sei = se, data = df)
+
+  df.agg.subgroups <- metafor::aggregate.escalc(subset(df.agg.mfr, multiple_es == "groups"),
+                                                cluster = author,
+                                                struct = "ID",
+                                                weighted = TRUE)
+
+  df.agg.outcomes <- metafor::aggregate.escalc(subset(df.agg.mfr, multiple_es == "outcomes"),
+                                               cluster = author,
+                                               struct = "CS",
+                                               weighted = FALSE,
+                                               rho = 0.5)
+  df.mfr <- rbind(subset(df.agg.mfr, is.na(multiple_es)),
+                  df.agg.subgroups,
+                  df.agg.outcomes)
+
+  ########## test MA means/SD SMD
+  umb <- umbrella(df, mult.level = TRUE, verbose = FALSE)[[1]]$random
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.mfr, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+
+  ########## test MA means/SD G
+  df$measure = "G"
+  umb <- mfr <- NA
+  umb <- umbrella(df, mult.level = TRUE, verbose = FALSE)[[1]]$random
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.mfr, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+
+  ########## test MA value G
+  df <- subset(df, select = -c(mean_cases, mean_controls))
+  umb <- mfr <- NA
+  umb <- umbrella(df, mult.level = TRUE, verbose = FALSE)[[1]]$random
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.mfr, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+})
+
+
+## MULT GROUPS - OR
+test_that("correct aggregation multiple groups", {
+  df <- subset(df.OR.multi, meta_review == "Huynh")
+
+  umb <- umbrella(df, mult.level = TRUE, method.var = "REML", verbose = FALSE)[[1]]$random
+
+  OR = with(df, .estimate_or_from_n(n_cases_exp, n_cases_nexp, n_controls_exp, n_controls_nexp))
+
+  df$value = OR$value
+  df$se = OR$se
+
+  df.agg.mfr <- metafor::escalc(yi = log(value), sei = se, data = df)
+
+  df.agg <- metafor::aggregate.escalc(x = df.agg.mfr, cluster = paste(df.agg.mfr$author, df.agg.mfr$year),
+                                      struct = "ID", weighted = TRUE)
+
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.agg, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+})
+
+## MULT OUTCOMES - OR
+test_that("correct aggregation multiple outcomes", {
+  df <- subset(df.OR.multi, meta_review == "el-Abood")
+
+  umb <- umbrella(df, mult.level = TRUE, method.var = "REML", verbose = FALSE)[[1]]$random
+
+  OR = with(df, .estimate_or_from_n(n_cases_exp, n_cases_nexp, n_controls_exp, n_controls_nexp))
+
+  df$value = OR$value
+  df$se = OR$se
+
+  df.agg.mfr <- metafor::escalc(yi = log(value), sei = se, data = df)
+
+  df.agg <- metafor::aggregate.escalc(x = df.agg.mfr, cluster = paste(df.agg.mfr$author, df.agg.mfr$year),
+                                      struct = "CS",
+                                      weighted = FALSE,
+                                      rho = 0.5)
+
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.agg, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+})
+
+
+## MULT GROUPS - RR
+test_that("correct aggregation multiple groups", {
+  df <- subset(df.OR.multi, meta_review == "Huynh", select = -c(value, ci_lo, ci_up))
+  df$measure = "RR"
+
+  umb <- umbrella(df, mult.level = TRUE, method.var = "REML", verbose = FALSE)[[1]]$random
+
+  RR = with(df, .estimate_rr_from_n(n_cases_exp,
+                                    n_cases_exp + n_controls_exp,
+                                    n_cases_nexp,
+                                    n_cases_nexp + n_controls_nexp))
+
+  df$value = RR$value
+  df$se = RR$se
+
+  df.agg.mfr <- metafor::escalc(yi = log(value), sei = se, data = df)
+
+  df.agg <- metafor::aggregate.escalc(x = df.agg.mfr, cluster = paste(df.agg.mfr$author, df.agg.mfr$year),
+                                      struct = "ID", weighted = TRUE)
+
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.agg, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+})
+
+## MULT OUTCOMES - OR
+test_that("correct aggregation multiple outcomes", {
+  df <- subset(df.OR.multi, meta_review == "el-Abood", select = -c(value, ci_lo, ci_up))
+  df$measure = "RR"
+
+  umb <- umbrella(df, mult.level = TRUE, method.var = "REML", verbose = FALSE)[[1]]$random
+
+  RR = with(df, .estimate_rr_from_n(n_cases_exp,
+                                    n_cases_exp + n_controls_exp,
+                                    n_cases_nexp,
+                                    n_cases_nexp + n_controls_nexp))
+
+  df$value = RR$value
+  df$se = RR$se
+
+  df.agg.mfr <- metafor::escalc(yi = log(value), sei = se, data = df)
+
+  df.agg <- metafor::aggregate.escalc(x = df.agg.mfr,
+                                      cluster = paste(df.agg.mfr$author, df.agg.mfr$year),
+                                      struct = "CS",
+                                      weighted = FALSE,
+                                      rho = 0.5)
+
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.agg, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+})
+
+## MULT GROUPS - HR
+test_that("correct aggregation multiple groups", {
+  df = df.OR.multi
+  df$n_cases = with(df, n_cases_exp + n_cases_nexp)
+  df$n_controls = with(df, n_controls_exp + n_controls_nexp)
+  df$se = with(df, (log(ci_up) - log(ci_lo)) / 3.92)
+
+  df <- subset(df, meta_review == "Huynh", select = -c(ci_up, ci_lo, n_cases_exp, n_cases_nexp, n_controls_exp, n_controls_nexp))
+  df$measure = "HR"
+
+  umb <- umbrella(df, mult.level = TRUE, method.var = "REML", verbose = FALSE)[[1]]$random
+
+  df.agg.mfr <- metafor::escalc(yi = log(value), sei = se, data = df)
+
+  df.agg <- metafor::aggregate.escalc(x = df.agg.mfr, cluster = paste(df.agg.mfr$author, df.agg.mfr$year),
+                                      struct = "ID", weighted = TRUE)
+
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.agg, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+})
+
+## MULT OUTCOMES - HR
+test_that("correct aggregation multiple outcomes", {
+  df = df.OR.multi
+  df$n_cases = with(df, n_cases_exp + n_cases_nexp)
+  df$n_controls = with(df, n_controls_exp + n_controls_nexp)
+  df$se = with(df, (log(ci_up) - log(ci_lo)) / 3.92)
+
+  df <- subset(df, meta_review == "el-Abood", select = -c(ci_up, ci_lo, n_cases_exp, n_cases_nexp, n_controls_exp, n_controls_nexp))
+  df$measure = "HR"
+
+  umb <- umbrella(df, mult.level = TRUE, method.var = "REML", verbose = FALSE)[[1]]$random
+
+  df.agg.mfr <- metafor::escalc(yi = log(value), sei = se, data = df)
+
+  df.agg <- metafor::aggregate.escalc(x = df.agg.mfr,
+                                      cluster = paste(df.agg.mfr$author, df.agg.mfr$year),
+                                      struct = "CS",
+                                      weighted = FALSE,
+                                      rho = 0.5)
+
+  mfr <- metafor::rma(yi = yi, vi = vi, data = df.agg, method = "REML")
+
+  expect_equal(umb$value, as.numeric(as.character(mfr$beta)), tolerance = tol_large)
+  expect_equal(umb$p.value, mfr$pval, tolerance = tol_large)
+})
+
+
 # SHARED_CONTROLS
 
 # CORRECTION FACTOR - simple level
@@ -197,7 +414,7 @@ test_that(".shared_adjustment_mod provides adequate sample size correction for s
 
   adj <- .shared_adjustment_mod(shared = df$shared_controls, author = df$author, year = df$year)
 
-  expect_equal(adj, c(1/3, 1/2, 1/2, 1/3, 1/3), tolerance = 1e-15)
+  expect_equal(adj, c(1/3, 1/2, 1/2, 1/3, 1/3), tolerance = tol_large)
 })
 
 # CORRECTION FACTOR - multi level
@@ -210,11 +427,11 @@ test_that(".shared_adjustment_mod provides adequate sample size correction for m
 
   df$shared_controls <- c(1,2,2,1,1)
   adj <- .shared_adjustment_mod(shared = df$shared_controls, author = df$author, year = df$year)
-  expect_equal(adj, c(1/2, 1/2, 1/2, 1/2, 1/2), tolerance = 1e-15)
+  expect_equal(adj, c(1/2, 1/2, 1/2, 1/2, 1/2), tolerance = tol_large)
 
   df$shared_controls <- c(NA,2,2,NA,NA)
   adj <- .shared_adjustment_mod(shared = df$shared_controls, author = df$author, year = df$year)
-  expect_equal(adj, c(1, 1/2, 1/2, 1, 1), tolerance = 1e-15)
+  expect_equal(adj, c(1, 1/2, 1/2, 1, 1), tolerance = tol_large)
 })
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - SMD
@@ -224,16 +441,16 @@ test_that(".shared_adjustment_mod provides adequate sample size and effect size
   df$shared_controls <- c(1,2,2,3,4)
 
 
-  umb <- .quiet(umbrella(df))
+  umb <- umbrella(df, verbose = FALSE)
 
   df_adj <- umb[[1]]$x_shared
 
   # not adjusted values should be equal to original ones
   expect_equal(df_adj$n_cases_raw, df$n_cases)
   expect_equal(df_adj$n_controls_raw, df$n_controls)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = tol_large)
 
 
   # adjusted values
@@ -258,13 +475,13 @@ test_that(".shared_adjustment_mod provides adequate sample size and effect size
   ci_upG2 <- tmp3G$value + tmp3G$se * qt(0.975, (df$n_cases[3]) + (df$n_controls[3] / 2) - 2)
 
   expect_equal(df_adj[2:3, ]$n_cases_raw, df[2:3, ]$n_cases)
-  expect_equal(df_adj[2:3, ]$n_controls_adj, df[2:3, ]$n_controls / 2, tolerance = 1e-6)
-  expect_equal(sum(df_adj$n_cases_adj, df_adj$n_controls_adj), umb$Pharmacological$n$cases_and_controls, tolerance = 1e-6)
+  expect_equal(df_adj[2:3, ]$n_controls_adj, df[2:3, ]$n_controls / 2, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_adj, df_adj$n_controls_adj), umb$Pharmacological$n$cases_and_controls, tolerance = tol_large)
 
-  expect_equal(df_adj$ci_lo_adj[2], ci_loG1, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_adj[2], ci_upG1, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_adj[3], ci_loG2, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_adj[3], ci_upG2, tolerance = 1e-6)
+  expect_equal(df_adj$ci_lo_adj[2], ci_loG1, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_adj[2], ci_upG1, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_adj[3], ci_loG2, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_adj[3], ci_upG2, tolerance = tol_large)
 })
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - multilevel - SMD
 test_that(".shared_adjustment_mod provides adequate sample size and effect size correction for MULTILEVEL situations SMD", {
@@ -279,16 +496,16 @@ test_that(".shared_adjustment_mod provides adequate sample size and effect size
   df$multiple_es <- NA ; df$multiple_es[c(1,4)] <- "outcomes"
   adj <- .shared_adjustment_mod(shared = df$shared_controls, author = df$author, year = df$year)
 
-  umb <- .quiet(umbrella(df, mult.level = TRUE))
+  umb <- umbrella(df, mult.level = TRUE, verbose = FALSE)
 
   df_adj <- umb[[1]]$x_shared
 
   # not adjusted values should be equal to original ones
   expect_equal(df_adj$n_cases_raw, df$n_cases)
   expect_equal(df_adj$n_controls_raw, df$n_controls)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = tol_large)
 
   # adjusted values
   tmp1 <- .estimate_d_from_means(n_cases = df$n_cases[1], n_controls = df$n_controls[1] / 2,
@@ -312,12 +529,12 @@ test_that(".shared_adjustment_mod provides adequate sample size and effect size
   ci_upG4 <- tmpG4$value + tmpG4$se * qt(0.975, df$n_cases[4] + df$n_controls[4] / 2 - 2)
 
   expect_equal(df_adj$n_cases_raw, df$n_cases)
-  expect_equal(df_adj$n_controls_adj, df$n_controls / 2, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_adj[1], ci_loG1, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_adj[1], ci_upG1, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_adj[4], ci_loG4, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_adj[4], ci_upG4, tolerance = 1e-6)
-  expect_equal(sum(df_adj$n_cases_raw[2:5], df_adj$n_controls_adj[2:5]), umb$Pharmacological$n$cases_and_controls, tolerance = 1e-6)
+  expect_equal(df_adj$n_controls_adj, df$n_controls / 2, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_adj[1], ci_loG1, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_adj[1], ci_upG1, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_adj[4], ci_loG4, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_adj[4], ci_upG4, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_raw[2:5], df_adj$n_controls_adj[2:5]), umb$Pharmacological$n$cases_and_controls, tolerance = tol_large)
 
 })
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - OR - shared_controls
@@ -326,16 +543,16 @@ test_that("shared_controls provides adequate sample size and effect size correct
 
   df$shared_controls <- c(1,2,2,3,4)
 
-  umb <- .quiet(umbrella(df))
+  umb <- umbrella(df, verbose = FALSE)
 
   df_adj <- umb[[1]]$x_shared
 
   # not adjusted values should be equal to original ones
   expect_equal(df_adj$n_cases_raw, df$n_cases)
   expect_equal(df_adj$n_controls_raw, df$n_controls)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = tol_large)
 
   # adjusted values
   tmp2 <- .estimate_or_from_n(n_cases_exp = df$n_cases_exp[2], n_cases_nexp = df$n_cases_nexp[2],
@@ -349,11 +566,11 @@ test_that("shared_controls provides adequate sample size and effect size correct
   ci_up_3 <- tmp3$value * exp(qnorm(0.975) * tmp3$se)
 
   expect_equal(df_adj[2:3, ]$n_cases_raw, df[2:3, ]$n_cases)
-  expect_equal(df_adj[2:3, ]$n_controls_adj, df[2:3, ]$n_controls / 2, tolerance = 1e-6)
-  expect_equal(sum(df_adj$n_cases_raw, df_adj$n_controls_adj), umb$ADHD$n$cases_and_controls, tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]), tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = 1e-6)
+  expect_equal(df_adj[2:3, ]$n_controls_adj, df[2:3, ]$n_controls / 2, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_raw, df_adj$n_controls_adj), umb$ADHD$n$cases_and_controls, tolerance = tol_large)
+  expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]), tolerance = tol_large)
+  expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = tol_large)
+  expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = tol_large)
 })
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - OR - shared_nexp
@@ -362,7 +579,7 @@ test_that("shared_nexp provides adequate sample size and effect size correction
 
   df$shared_nexp <- c(1,2,2,3,4)
 
-  umb <- .quiet(umbrella(df))
+  umb <- umbrella(df, verbose = FALSE)
 
   df_adj <- umb[[1]]$x_shared
 
@@ -371,9 +588,9 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   expect_equal(df_adj$n_controls_exp_raw, df$n_controls_exp)
   expect_equal(df_adj$n_cases_nexp_raw, df$n_cases_nexp)
   expect_equal(df_adj$n_controls_nexp_raw, df$n_controls_nexp)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = tol_large)
 
   # adjusted values
   tmp2 <- .estimate_or_from_n(n_cases_exp = df$n_cases_exp[2], n_cases_nexp = df$n_cases_nexp[2] / 2,
@@ -387,9 +604,9 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   ci_up_3 <- tmp3$value * exp(qnorm(0.975) * tmp3$se)
 
   expect_equal(df_adj[2:3, ]$n_nexp_adj, df[2:3, ]$n_nexp/2)
-  expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]), tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = 1e-6)
+  expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]), tolerance = tol_large)
+  expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = tol_large)
+  expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = tol_large)
 })
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - multilevel - OR - shared_nexp
@@ -406,16 +623,16 @@ test_that("shared_controls provides adequate sample size and effect size correct
 
   adj <- .shared_adjustment_mod(shared = df$shared_controls, author = df$author, year = df$year)
 
-  umb <- .quiet(umbrella(df, mult.level = TRUE))
+  umb <- umbrella(df, mult.level = TRUE, verbose = FALSE)
 
   df_adj <- umb[[1]]$x_shared
 
   # not adjusted values should be equal to original ones
   expect_equal(df_adj$n_cases_raw, df$n_cases)
   expect_equal(df_adj$n_controls_raw, df$n_controls)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = tol_large)
 
   se = NA
   # adjusted values
@@ -428,11 +645,11 @@ test_that("shared_controls provides adequate sample size and effect size correct
   ci_up <- df$value * exp(qnorm(0.975) * se)
 
   expect_equal(df_adj$n_cases_raw, df$n_cases)
-  expect_equal(df_adj$n_controls_adj, df$n_controls / 2, tolerance = 1e-6)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_adj, ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_adj, ci_up, tolerance = 1e-6)
-  expect_equal(sum(df_adj$n_cases_adj[c(1:3,5)], df_adj$n_controls_adj[c(1:3,5)]), umb$ADHD$n$cases_and_controls, tolerance = 1e-6)
+  expect_equal(df_adj$n_controls_adj, df$n_controls / 2, tolerance = tol_large)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_adj, ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_adj, ci_up, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_adj[c(1:3,5)], df_adj$n_controls_adj[c(1:3,5)]), umb$ADHD$n$cases_and_controls, tolerance = tol_large)
 })
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple MULTILEVEL - OR - shared_nexp
@@ -447,7 +664,7 @@ test_that("shared_nexp provides adequate sample size and effect size correction
 
   df$multiple_es <- NA ; df$multiple_es[c(1,4)] <- "outcomes"
 
-  umb <- .quiet(umbrella(df, mult.level = TRUE))
+  umb <- umbrella(df, mult.level = TRUE, verbose = FALSE)
 
   df_adj <- umb[[1]]$x_shared
 
@@ -456,9 +673,9 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   expect_equal(df_adj$n_controls_exp_raw, df$n_controls_exp)
   expect_equal(df_adj$n_cases_nexp_raw, df$n_cases_nexp)
   expect_equal(df_adj$n_controls_nexp_raw, df$n_controls_nexp)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = tol_large)
 
   # adjusted values
   se <- .estimate_or_from_n(n_cases_exp = df$n_cases_exp, n_cases_nexp = df$n_cases_nexp / 2,
@@ -470,21 +687,20 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   expect_equal(df_adj$n_cases_nexp_adj, df$n_cases_nexp / 2)
   expect_equal(df_adj$n_controls_nexp_adj, df$n_controls_nexp / 2)
 
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_adj, ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_adj, ci_up, tolerance = 1e-6)
-  expect_equal(sum(df_adj$n_cases_adj[c(1:3,5)], df_adj$n_controls_adj[c(1:3,5)]), umb$ADHD$n$cases_and_controls, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_adj, ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_adj, ci_up, tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_adj[c(1:3,5)], df_adj$n_controls_adj[c(1:3,5)]), umb$ADHD$n$cases_and_controls, tolerance = tol_large)
 })
 
 
 # SAMPLE SIZE and EFFECT SIZE ESTIMATE - simple level - RR
 test_that("shared_nexp provides adequate sample size and effect size correction for STANDARD situations RR", {
-
   df <- df.RR[1:5,]
 
   df$shared_nexp <- c(1,2,2,3,4)
 
-  umb <- .quiet(umbrella(df))
+  umb <- umbrella(df, verbose = FALSE)
 
   df_adj <- umb[[1]]$x_shared
 
@@ -493,9 +709,9 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   expect_equal(df_adj$n_exp_raw, df$n_exp)
   expect_equal(df_adj$n_cases_nexp_raw, df$n_cases_nexp)
   expect_equal(df_adj$n_nexp_raw, df$n_nexp)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = tol_large)
 
   # adjusted values
   tmp2 <- .estimate_rr_from_n(n_cases_exp = df$n_cases_exp[2], n_cases_nexp = df$n_cases_nexp[2] / 2,
@@ -513,9 +729,9 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   expect_equal(df_adj[2:3, ]$n_cases_nexp_adj, df[2:3, ]$n_cases_nexp / 2)
   expect_equal(df_adj[2:3, ]$n_nexp_adj, df[2:3, ]$n_nexp / 2)
   #
-  expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]), tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = 1e-6)
+  expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]), tolerance = tol_large)
+  expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = tol_large)
+  expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = tol_large)
 })
 
 
@@ -527,16 +743,16 @@ test_that("shared_nexp provides adequate sample size and effect size correction
 
   df$shared_nexp <- c(1,2,2,3,4)
 
-  umb <- .quiet(umbrella(df))
+  umb <- umbrella(df, verbose = FALSE)
 
   df_adj <- umb[[1]]$x_shared
 
   # not adjusted values should be equal to original ones
   expect_equal(df_adj$n_cases_exp_raw, df$n_cases_exp)
   expect_equal(df_adj$time_exp_raw, df$time_exp)
-  expect_equal(df_adj$value_raw, df$value, tolerance = 1e-6)
-  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = 1e-6)
-  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = 1e-6)
+  expect_equal(df_adj$value_raw, df$value, tolerance = tol_large)
+  expect_equal(df_adj$ci_lo_raw, df$ci_lo, tolerance = tol_large)
+  expect_equal(df_adj$ci_up_raw, df$ci_up, tolerance = tol_large)
 
   # adjusted values
   tmp2 <- .estimate_irr_from_n(n_cases_exp = df$n_cases_exp[2],
@@ -556,9 +772,9 @@ test_that("shared_nexp provides adequate sample size and effect size correction
   expect_equal(df_adj[2:3, ]$n_cases_exp_adj, df[2:3, ]$n_cases_exp)
   expect_equal(df_adj[2:3, ]$n_cases_nexp_adj, df[2:3, ]$n_cases_nexp / 2)
 
-  expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]), tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = 1e-6)
-  expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = 1e-6)
-  expect_equal(sum(df_adj$n_cases_adj), umb$Smoking$n$cases_and_controls, tolerance = 1e-6)
+  expect_equal(df_adj[2:3, ]$value_adj, c(df$value[2], df$value[3]))
+  expect_equal(df_adj[2:3, ]$ci_lo_adj, c(ci_lo_2, ci_lo_3), tolerance = tol_large)
+  expect_equal(df_adj[2:3, ]$ci_up_adj, c(ci_up_2, ci_up_3), tolerance = tol_large)
+  expect_equal(sum(df_adj$n_cases_adj), umb$Smoking$n$cases_and_controls, tolerance = tol_large)
 })
 
